@@ -1,13 +1,9 @@
-# Copyright (c) 2020, Matt Layman
-
 import sys
 
 import pytest
 from tap.formatter import format_as_diagnostics
 from tap.tracker import Tracker
 
-from pytest_tap.i18n import _
-
 # Because of how pytest hooks work, there is not much choice
 # except to use module level state. Ugh.
 tracker = Tracker()
@@ -21,24 +17,24 @@ def pytest_addoption(parser):
         "--tap-stream",
         default=False,
         action="store_true",
-        help=_("Stream TAP output instead of the default test runner output."),
+        help="Stream TAP output instead of the default test runner output.",
     )
     group.addoption(
         "--tap-files",
         default=False,
         action="store_true",
-        help=_("Store all TAP test results into individual files per test case."),
+        help="Store all TAP test results into individual files per test case.",
     )
     group.addoption(
         "--tap-combined",
         default=False,
         action="store_true",
-        help=_("Store all TAP test results into a combined output file."),
+        help="Store all TAP test results into a combined output file.",
     )
     group.addoption(
         "--tap-outdir",
         metavar="path",
-        help=_(
+        help=(
             "An optional output directory to write TAP files to. "
             "If the directory does not exist, it will be created."
         ),
@@ -48,16 +44,21 @@ def pytest_addoption(parser):
 @pytest.mark.trylast
 def pytest_configure(config):
     """Set all the options before the test run."""
+    # The help printing uses the terminalreporter,
+    # which is unregistered by the streaming mode.
+    if config.option.help:
+        return
+
     global ENABLED
     ENABLED = (
-        config.getoption("tap_stream")
-        or config.getoption("tap_combined")
-        or config.getoption("tap_files")
+        config.option.tap_stream
+        or config.option.tap_combined
+        or config.option.tap_files
     )
 
-    tracker.outdir = config.getoption("tap_outdir")
-    tracker.combined = config.getoption("tap_combined")
-    if config.getoption("tap_stream"):
+    tracker.outdir = config.option.tap_outdir
+    tracker.combined = config.option.tap_combined
+    if config.option.tap_stream:
         reporter = config.pluginmanager.getplugin("terminalreporter")
         if reporter:
             config.pluginmanager.unregister(reporter)
@@ -72,11 +73,9 @@ def pytest_configure(config):
 
 def pytest_runtestloop(session):
     """Output the plan line first."""
-    if ENABLED:
-        if session.config.getoption("tap_stream") or session.config.getoption(
-            "tap_combined"
-        ):
-            tracker.set_plan(session.testscollected)
+    option = session.config.option
+    if ENABLED and (option.tap_stream or option.tap_combined):
+        tracker.set_plan(session.testscollected)
 
 
 def pytest_runtest_logreport(report):
@@ -119,7 +118,7 @@ def pytest_runtest_logreport(report):
         # pytest treats an unexpected success from unitest.expectedFailure as a failure.
         # To match up with TAPTestResult and the TAP spec, treat the pass
         # as an ok with a todo directive instead.
-        if isinstance(report.longrepr, str) and "Unexpected success" in report.longrepr:
+        if "Unexpected success" in str(report.longrepr):
             tracker.add_ok(testcase, description, directive="TODO unexpected success")
             return
 
